part of cresce_ui;

class CInputDropdown<T> extends StatefulWidget {
  final String label;
  final List<T> items;
  final void Function(T? value)? onChanged;
  final bool setInitialValue;

  const CInputDropdown({
    Key? key,
    required this.label,
    required this.items,
    this.onChanged,
    this.setInitialValue = false,
  }) : super(key: key);

  @override
  State<CInputDropdown<T>> createState() => _CDropDownState<T>();
}

class _CDropDownState<T> extends State<CInputDropdown<T>> {
  late T? currentValue;

  @override
  void initState() {
    super.initState();
    currentValue = null;
    if (widget.setInitialValue && widget.items.isNotEmpty) {
      currentValue = widget.items.first;
      widget.onChanged?.call(currentValue);
    }
  }

  @override
  Widget build(BuildContext context) {
    return DropdownButton<T>(
      isExpanded: true,
      hint: CText(
        label: widget.label,
        style: CTextStyles.fieldSecondaryVar1,
      ),
      value: currentValue,
      icon: Icon(
        FontAwesomeIcons.caretDown,
        color: CColors.primary,
        size: 16,
      ),
      underline: const CDivider(),
      items: widget.items
          .map(
            (item) => DropdownMenuItem<T>(
              value: item,
              child: CText(
                label: item.toString(),
                style: CTextStyles.fieldSecondaryVar1,
              ),
            ),
          )
          .toList(),
      onChanged: (T? value) {
        widget.onChanged?.call(value);
        setState(() {
          currentValue = value;
        });
      },
    );
  }
}
